From 3d21856023cf97279f8b0f0ee62f6e4c9acb916e Mon Sep 17 00:00:00 2001
From: Mark Cox <markcox80@gmail.com>
Date: Wed, 24 Oct 2012 21:53:51 +1000
Subject: [PATCH 1/2] Handle multiple ASDF:OUTPUT-FILES in CFFI-GROVEL.

---
 grovel/asdf.lisp | 25 ++++++++++++++++---------
 1 file changed, 16 insertions(+), 9 deletions(-)

diff --git a/grovel/asdf.lisp b/grovel/asdf.lisp
index a02ff4c..fd2ecc7 100644
--- a/grovel/asdf.lisp
+++ b/grovel/asdf.lisp
@@ -54,11 +54,20 @@ operations that take care of calling PROCESS-GROVEL-FILE in order
 to generate a Lisp file that is subsequently compiled and/or
 loaded.")))
 
+#-ecl
+(defun %compile-file-to-pathname (input-file output-file)
+  (compile-file input-file :output-file output-file))
+
+#+ecl
+(defun %compile-file-to-pathname (input-file output-file)
+  (if (pathname-match-p output-file (compile-file-pathname input-file :type :object))
+      (compile-file input-file :output-file output-file :system-p t)
+      (compile-file input-file :output-file output-file)))
+
 (defmethod asdf:perform ((op asdf:compile-op) (c grovel-file))
-  (let ((output-file (ensure-pathname (car (asdf:output-files op c)))))
-    (compile-file (process-grovel-file (asdf:component-pathname c) output-file)
-                  :output-file output-file
-                  #+ecl :system-p #+ecl t)))
+  (dolist (output-file (mapcar #'ensure-pathname (asdf:output-files op c)))
+    (%compile-file-to-pathname (process-grovel-file (asdf:component-pathname c) output-file)
+                               output-file)))
 
 (defmethod asdf:perform ((op asdf:load-source-op) (c grovel-file))
   (load (process-grovel-file
@@ -85,11 +94,9 @@ that are subsequently compiled and/or loaded.")))
             fasl-file)))
 
 (defmethod asdf:perform ((op asdf:compile-op) (c wrapper-file))
-  (multiple-value-bind (generated-source-file fasl-file)
-      (%perform-process-wrapper-file op c)
-    (compile-file generated-source-file
-                  :output-file fasl-file
-                  #+ecl :system-p #+ecl t)))
+  (let ((generated-source-file (%perform-process-wrapper-file op c)))
+    (dolist (output-file (mapcar #'ensure-pathname (asdf:output-files op c)))
+      (%compile-file-to-pathname generated-source-file output-file))))
 
 (defmethod asdf:perform ((op asdf:load-source-op) (c wrapper-file))
   (load (%perform-process-wrapper-file op c)))
-- 
1.8.0

